@@ -2,6 +2,7 @@
 #' @param x A valid R `object` for which `na_counts` are needed.
 #' @param grouping_cols A character vector. If supplied, one can provide the columns by which to group the
 #' data.
+#' @param exclude_cols Columns to exclude from the analysis.
 #' @description This function takes a `data.frame` object as an input and returns the corresponding
 #' `NA` counts. `NA` refers to R's builtin missing data holder.
 #' @importFrom dplyr %>%
@@ -13,33 +14,33 @@
 #' # Grouped counts
 #' test <- data.frame(Subject = c("A","A","B","B"), res = c(NA,1,2,3),
 #' ID = c("1","1","2","2"))
-#' get_na_counts(test,grouping_cols =
-#'                         c("ID", "Subject"))
+#' get_na_counts(test,grouping_cols = c("ID", "Subject"))
 #' @export
 
-get_na_counts <- function(x, grouping_cols = NULL){
+get_na_counts <- function(x, grouping_cols = NULL, exclude_cols=NULL){
   UseMethod("get_na_counts")
 }
 
 #' @export
 
-get_na_counts.data.frame <- function(x, grouping_cols = NULL){
+get_na_counts.data.frame <- function(x, grouping_cols = NULL, exclude_cols = NULL){
 
 if(! is.null(grouping_cols)){
-if(any(!grouping_cols %in% names(x))){
-  stop("All grouping columns must exist in the data set")
-}
-  x %>%
-    dplyr::group_by(!!!dplyr::syms(grouping_cols)) %>%
-    dplyr::summarise(dplyr::across(dplyr::everything(),
-                                   ~sum(is.na(.))))
+check_column_existence(x, grouping_cols, unique_name = "to group by")
+x <- x %>% dplyr::group_by(!!!dplyr::syms(grouping_cols))
 
 }
 
-  else{
+if(! is.null(exclude_cols)){
+
+check_column_existence(x, exclude_cols,unique_name = "to exclude")
+
+x <- x %>% dplyr::select(-all_of(exclude_cols))
+
+}
+
+x %>% dplyr::summarise(dplyr::across(dplyr::everything(), ~sum(is.na(.))))
 
-    colSums(is.na(x))
-  }
 
 }
 
