@@ -1,8 +1,8 @@
 #' Sort Variables according to missingness
 #' @description Provides a useful way to sort the variables(columns) according
 #' to their missingness.
-#' @inheritParams get_na_counts
 #' @importFrom utils stack
+#' @param df A data.frame object 
 #' @param sort_by One of counts or percents. This determines whether the results are sorted by counts or percentages.
 #' @param descending Logical. Should missing values be sorted in decreasing order ie largest to smallest? Defaults to FALSE.
 #' @param ... Other arguments to specific functions. See "See also below"
@@ -19,41 +19,35 @@
 # That would make it easier to just define a new sort method
 # Would require a lot of time to give classes, decided to write it
 # From "scratch"
-sort_by_missingness <- function(x, sort_by = "counts",
+sort_by_missingness <- function(df, sort_by = "counts",
                                 descending = FALSE, ...){
   UseMethod("sort_by_missingness")
 }
 
 #' @export
 # This will fail for grouped percentages
-sort_by_missingness.data.frame <- function(x, sort_by = "counts",
+sort_by_missingness.data.frame <- function(df, sort_by = "counts",
                                         descending = FALSE,
                                         ...){
+  
+unexpected_argument(sort_by,c("counts", "percents"))
 
-  if(!sort_by %in% c("counts", "percents")){
-    stop("sort_by should be one of counts or percents")
-  }
+use_df <-get_na_counts(df,...)
 
-  if(sort_by =="counts"){
+if(sort_by=="percents") use_df <- percent_missing(df,...)
 
-    res<-sort(get_na_counts(x,...), decreasing = descending)
+# Change to a vector to avoid issues with sort on dataframes
+use_df_counts <- as.numeric(use_df)
 
-  }
+res <- use_df[sort(use_df_counts,decreasing=descending, index.return=TRUE)[[2]]]
 
 
-
-else{
-
-      res<-sort(percent_missing(x,...), decreasing = descending)
-
-
-    }
-
 # Make result more "sensible" res -h
 
-  res_stacked <- stack(res)[,c(2,1)]
-  names(res_stacked) <- c("variable","percent")
-  res_stacked
+res_stacked <- stack(res)[,c(2,1)]
+names(res_stacked) <- c("variable","percent") 
+res_stacked
+
 
 }
 
