@@ -165,6 +165,18 @@ partial_match <- data.frame(A=c("Hi","match_me","nope"), B=c(NA, "not_me","nah")
 recode_as_na_str(partial_match,"ends_with","ME", case_sensitive=FALSE)
 
 
+## -----------------------------------------------------------------------------
+
+head(recode_as_na_for(airquality,criteria="gt",value=25))
+
+
+
+
+## -----------------------------------------------------------------------------
+
+head(recode_as_na_for(airquality, value=40,subset_cols=c("Solar.R","Ozone"), criteria="gt"))
+
+
 ## -----------------------------------------------------------------------------
 
 head(recode_na_as(airquality))
@@ -250,6 +262,15 @@ head(drop_na_if(airquality, percent_na = 24, keep_columns = "Ozone"))
 head(drop_na_if(airquality, percent_na = 24))
 
 
+## -----------------------------------------------------------------------------
+grouped_drop <- structure(list(ID = c("A", "A", "B", "A", "B"), 
+          Vals = c(4, NA,  NA, NA, NA), Values = c(5, 6, 7, 8, NA)), 
+          row.names = c(NA, -5L), class = "data.frame")
+# Drop all columns for groups that meet a percent missingness of greater than or
+# equal to 67
+drop_na_if(grouped_drop,percent_na = 67,sign="gteq",
+                                    grouping_cols = "ID")
+
 ## -----------------------------------------------------------------------------
 # Drop rows with at least two NAs
 head(drop_row_if(airquality, sign="gteq", type="count" , value = 2))
@@ -266,22 +287,9 @@ head(drop_na_at(airquality,pattern_type = "starts_with","O"))
 
 
 
-## -----------------------------------------------------------------------------
-
-head(recode_as_na_for(airquality,criteria="gt",value=25))
-
-
-
-
-## -----------------------------------------------------------------------------
-
-head(recode_as_na_for(airquality, value=40,subset_cols=c("Solar.R","Ozone"), criteria="gt"))
-
-
 ## -----------------------------------------------------------------------------
 
 test2 <- data.frame(ID= c("A","A","B","A","B"), Vals = c(4,rep(NA, 4))) 
-
 drop_all_na(test2, grouping_cols="ID")
 
 
