@@ -6,7 +6,7 @@ test_that(desc="get_na_counts works as expected",
                                          3)
                   expect_error(get_na_counts(airquality,
                                                        grouping_cols = "Nope"),
-                                         "All grouping columns must exist in the data set",
+                                         "All columns to group by should exist in the data set",
                                          fixed=TRUE)
                   expect_equal(nrow(get_na_counts(airquality,
                                                             grouping_cols = "Month")),
